@@ -1,18 +1,19 @@
 # coding=utf-8
 from __future__ import division
 
-from .location import Location
-from .designday import DesignDay
+import os
+
+from .analysisperiod import AnalysisPeriod
 from .datacollection import HourlyContinuousCollection
 from .datacollection import MonthlyCollection
-from .header import Header
-from .analysisperiod import AnalysisPeriod
 from .datatype import angle, distance, energyflux, energyintensity, generic, \
     illuminance, luminance, fraction, pressure, speed, temperature
-from .skymodel import calc_sky_temperature
+from .designday import DesignDay
 from .futil import write_to_file
+from .header import Header
+from .location import Location
+from .skymodel import calc_sky_temperature
 
-import os
 readmode = 'rb'
 try:
     from itertools import izip as zip  # python 2
@@ -74,14 +75,20 @@ class EPW(object):
         * liquid_precipitation_quantity
         * sky_temperature
     """
+    __slots__ = ('_file_path', '_is_header_loaded', '_is_data_loaded', '_is_ip',
+                 '_data','_metadata', '_heating_dict', '_cooling_dict', '_extremes_dict',
+                 '_extreme_hot_weeks', '_extreme_cold_weeks', '_typical_weeks',
+                 '_monthly_ground_temps', '_is_leap_year', 'daylight_savings_start',
+                 'daylight_savings_end', '_num_of_fields', 'comments_1', 'comments_2',
+                 '_location', '_header')
 
     def __init__(self, file_path):
-        """Initalize an EPW object from from a local .epw file.
+        """Initialize an EPW object from from a local .epw file.
         """
         self._file_path = os.path.normpath(file_path) if file_path is not None else None
         self._is_header_loaded = False
         self._is_data_loaded = False
-        self._is_ip = False  # track if collections have been coverted to IP
+        self._is_ip = False  # track if collections have been converted to IP
 
         # placeholders for the EPW data that will be imported
         self._data = []
@@ -98,12 +105,11 @@ class EPW(object):
         self.daylight_savings_end = '0'
         self.comments_1 = ''
         self.comments_2 = ''
-
         self._num_of_fields = 35  # it is 35 for TMY3 files
 
     @classmethod
     def from_missing_values(cls, is_leap_year=False):
-        """Initalize an EPW object with all data missing or empty.
+        """Initialize an EPW object with all data missing or empty.
 
         Note that this classmethod is intended for workflows where one plans
         to set all of the data within the EPW object.  The EPW file written
@@ -460,10 +466,10 @@ class EPW(object):
 
     @property
     def monthly_ground_temperature(self):
-        """Return a dictionary of Mothly Data collections.
+        """Return a dictionary of Monthly Data collections.
 
         The keys of this dictionary are the depths at which each set
-        of temperatures occurrs."""
+        of temperatures occurs."""
         self._load_header_check()
         return self._monthly_ground_temps
 
@@ -544,7 +550,7 @@ class EPW(object):
                 self._location.time_zone = location_data[8]
                 self._location.elevation = location_data[9]
 
-                # asemble a dictionary of metadata
+                # assemble a dictionary of metadata
                 self._metadata = {
                     'source': self._location.source,
                     'country': self._location.country,
@@ -598,9 +604,9 @@ class EPW(object):
                     header_meta['soil specific heat'] = grnd_data[st_ind + 3]
                     grnd_header = Header(temperature.GroundTemperature(), 'C',
                                          AnalysisPeriod(), header_meta)
-                    grnd_vlas = [float(x) for x in grnd_data[st_ind + 4: st_ind + 16]]
+                    grnd_vals = [float(x) for x in grnd_data[st_ind + 4: st_ind + 16]]
                     self._monthly_ground_temps[float(grnd_data[st_ind])] = \
-                        MonthlyCollection(grnd_header, grnd_vlas, list(xrange(12)))
+                        MonthlyCollection(grnd_header, grnd_vals, list(xrange(12)))
                     st_ind += 16
 
                 # parse leap year, daylight savings and comments.
@@ -1287,7 +1293,7 @@ pdfs/pdfs_v8.4.0/AuxiliaryPrograms.pdf (Chapter 2.9.1)
     def sky_temperature(self):
         """Return annual Sky Temperature as a Ladybug Data Collection.
 
-        This value in degrees Celcius is derived from the Horizontal Infrared
+        This value in degrees Celsius is derived from the Horizontal Infrared
         Radiation Intensity in Wh/m2. It represents the long wave radiant
         temperature of the sky
         Read more at: https://bigladdersoftware.com/epx/docs/8-9/engineering-reference\
@@ -1692,10 +1698,11 @@ class EPWField(object):
 
     Attributes:
         name: Name of the field.
-        type: field value type (e.g. int, float, str)
+        value_type: field value type (e.g. int, float, str)
         unit: Field unit.
         missing: Missing value for the data type in EPW files.
     """
+    __slots__ = ('name', 'value_type', 'unit', 'missing')
 
     def __init__(self, field_dict):
         self.name = field_dict['name']
